VeraCrypt
aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMounir IDRASSI <mounir.idrassi@idrix.fr>2019-10-25 22:46:17 +0200
committerMounir IDRASSI <mounir.idrassi@idrix.fr>2019-10-26 00:17:08 +0200
commit6bf37280d621d3c8fae85cf4e0533df0bc8334ca (patch)
treea43fd4dd1976f105c6c8642f53b705e3eaaf273d
parent38b5af907e5525eff87e82cc8cb504d37dfc15fc (diff)
downloadVeraCrypt-6bf37280d621d3c8fae85cf4e0533df0bc8334ca.tar.gz
VeraCrypt-6bf37280d621d3c8fae85cf4e0533df0bc8334ca.zip
MacOSX: use wxWidgets 3.1.2 for the legacy build which is now done with SDK 10.9 while still targeting OSX 10.7.
-rwxr-xr-xsrc/Build/build_veracrypt_macosx_legacy.sh9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/Build/build_veracrypt_macosx_legacy.sh b/src/Build/build_veracrypt_macosx_legacy.sh
index 0b0a4f96..70226f2e 100755
--- a/src/Build/build_veracrypt_macosx_legacy.sh
+++ b/src/Build/build_veracrypt_macosx_legacy.sh
@@ -12,21 +12,22 @@ SOURCEPATH=$(cd "$(dirname "$SCRIPTPATH/../.")"; pwd)
# directory where the VeraCrypt project has been checked out
PARENTDIR=$(cd "$(dirname "$SCRIPTPATH/../../../.")"; pwd)
-# the sources of wxWidgets 3.0.4 must be extracted to the parent directory
-export WX_ROOT=$PARENTDIR/wxWidgets-3.0.4
+# the sources of wxWidgets 3.1.2 must be extracted to the parent directory
+export WX_ROOT=$PARENTDIR/wxWidgets-3.1.2
echo "Using wxWidgets sources in $WX_ROOT"
# this will be the temporary wxWidgets directory
export WX_BUILD_DIR=$PARENTDIR/wxBuild
# define the SDK version to use. We use 10.7 by default
export VC_OSX_TARGET=10.7
+export VC_OSX_SDK=10.9
echo "Using MacOSX SDK $VC_OSX_TARGET"
cd $SOURCEPATH
echo "Building VeraCrypt"
-make WXSTATIC=1 wxbuild && make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package
+make WXSTATIC=FULL wxbuild && make WXSTATIC=FULL clean && make WXSTATIC=FULL && make WXSTATIC=FULL package
# Uncomment below and comment line above to reuse existing wxWidgets build
# make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package \ No newline at end of file
@@ -12,21 +12,22 @@ SOURCEPATH=$(cd "$(dirname "$SCRIPTPATH/../.")"; pwd)
# Uncomment below and comment line above to reuse existing wxWidgets build
-# make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package \ No newline at end of file
+# make WXSTATIC=FULL clean && make WXSTATIC=FULL && make WXSTATIC=FULL package